@@ -1,11 +1,8 @@
 package Plack::Middleware::DNSBL;
-
-use strict;
-use warnings;
-
 use parent qw(Plack::Middleware);
+use strict; use warnings;
 
-our $VERSION = '0.03002';
+our $VERSION = '0.03';
 
 use Carp ();
 use Plack::Util::Accessor qw(cache cache_time resolver blacklists blacklisted);
@@ -228,7 +225,7 @@ A L<Net::DNS::Resolver> object. Defaults to C<< Net::DNS::Resolver->new >>.
 =head1 WHITELISTING
 
 There's no build-in way of whitelisting IPs or certain paths, however this can
-be quickly solved by using L<Plack::Builder>'s C<enable_if>:
+be quickly solved by using Plack::Builder's C<enable_if>:
 
   builder {
       enable_if {
